document.addEventListener('DOMContentLoaded', function() {
  // Initialize balance chart
  const balanceCtx = document.getElementById('balanceChart').getContext('2d');
  const balanceChart = new Chart(balanceCtx, {
    type: 'line',
    data: {
      labels: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun'],
      datasets: [{
        label: 'Account Balance',
        data: [3200, 3500, 3800, 4200, 4700, 5247],
        borderColor: '#4361ee',
        backgroundColor: 'rgba(67, 97, 238, 0.1)',
        borderWidth: 2,
        tension: 0.3,
        fill: true
      }]
    },
    options: {
      responsive: true,
      maintainAspectRatio: false,
      plugins: {
        legend: {
          display: false
        }
      },
      scales: {
        y: {
          beginAtZero: false
        }
      }
    }
  });

  // Initialize spending chart
  const spendingCtx = document.getElementById('spendingChart').getContext('2d');
  const spendingChart = new Chart(spendingCtx, {
    type: 'doughnut',
    data: {
      labels: ['Housing', 'Food', 'Transportation', 'Entertainment', 'Utilities', 'Other'],
      datasets: [{
        data: [1200, 400, 300, 200, 150, 602.11],
        backgroundColor: [
          '#4361ee',
          '#4895ef',
          '#4cc9f0',
          '#f72585',
          '#7209b7',
          '#3a0ca3'
        ],
        borderWidth: 0
      }]
    },
    options: {
      responsive: true,
      maintainAspectRatio: false,
      plugins: {
        legend: {
          position: 'right'
        }
      }
    }
  });

  // Transaction filter functionality
  const filterButtons = document.querySelectorAll('.transaction-filters button:not(.add-button)');
  filterButtons.forEach(button => {
    button.addEventListener('click', function() {
      filterButtons.forEach(btn => btn.classList.remove('active'));
      this.classList.add('active');
      
      const filter = this.textContent.toLowerCase();
      const rows = document.querySelectorAll('.transaction-table tbody tr');
      
      rows.forEach(row => {
        if (filter === 'all') {
          row.style.display = '';
        } else {
          const type = row.querySelector('td:nth-child(3)').textContent.toLowerCase();
          const amountClass = row.querySelector('td:nth-child(4) span').className;
          
          if (
            (filter === 'income' && amountClass === 'income') ||
            (filter === 'expenses' && amountClass === 'expense') ||
            (type.includes(filter))
          ) {
            row.style.display = '';
          } else {
            row.style.display = 'none';
          }
        }
      });
    });
  });

  // Report period toggle
  const reportButtons = document.querySelectorAll('.report-options button');
  reportButtons.forEach(button => {
    button.addEventListener('click', function() {
      reportButtons.forEach(btn => btn.classList.remove('active'));
      this.classList.add('active');
      // In a real app, this would fetch new data for the selected period
    });
  });
});